package net.knarcraft.blacksmith;

import net.citizensnpcs.api.CitizensAPI;
import net.knarcraft.blacksmith.command.BlackSmithCommand;
import net.knarcraft.blacksmith.command.BlackSmithTabCompleter;
import net.knarcraft.blacksmith.config.GlobalSettings;
import net.knarcraft.blacksmith.listener.NPCClickListener;
import net.knarcraft.blacksmith.listener.PlayerListener;
import net.knarcraft.blacksmith.manager.EconomyManager;
import net.knarcraft.blacksmith.trait.BlacksmithTrait;
import org.bukkit.command.PluginCommand;
import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.plugin.PluginManager;
import org.bukkit.plugin.java.JavaPlugin;

import java.util.logging.Level;

/**
 * Blacksmith's main class
 */
public class BlacksmithPlugin extends JavaPlugin {

    private static BlacksmithPlugin instance;
    private GlobalSettings config;

    /**
     * Gets an instance of the Blacksmith plugin
     *
     * @return <p>An instance of the blacksmith plugin</p>
     */
    public static BlacksmithPlugin getInstance() {
        return instance;
    }

    /**
     * Gets settings for the blacksmith plugin
     *
     * @return <p>Settings for the blacksmith plugin</p>
     */
    public GlobalSettings getSettings() {
        return config;
    }

    /**
     * Reloads the configuration file from disk
     */
    public void reload() {
        config.load();
    }

    @Override
    public void onDisable() {
        getLogger().log(Level.INFO, " v" + getDescription().getVersion() + " disabled.");
    }

    @Override
    public void onEnable() {
        instance = this;

        FileConfiguration fileConfiguration = this.getConfig();
        this.saveDefaultConfig();
        fileConfiguration.options().copyDefaults(true);

        //Load settings
        config = new GlobalSettings(this);
        config.load();

        getLogger().log(Level.INFO, "Setting Up Vault now....");
        boolean canLoad = EconomyManager.setUp(getServer().getServicesManager(), getLogger());
        if (!canLoad) {
            getLogger().log(Level.SEVERE, "Vault Integration Failed....");
            getServer().getPluginManager().disablePlugin(this);
            return;
        }
        //Register the blacksmith trait with Citizens
        CitizensAPI.getTraitFactory().registerTrait(
                net.citizensnpcs.api.trait.TraitInfo.create(BlacksmithTrait.class).withName("blacksmith"));

        //Register the blacksmith main-command
        PluginCommand blacksmithCommand = this.getCommand("blacksmith");
        if (blacksmithCommand != null) {
            blacksmithCommand.setExecutor(new BlackSmithCommand());
            blacksmithCommand.setTabCompleter(new BlackSmithTabCompleter());
        }

        PluginManager pluginManager = getServer().getPluginManager();
        pluginManager.registerEvents(new PlayerListener(), this);
        pluginManager.registerEvents(new NPCClickListener(), this);

        getLogger().log(Level.INFO, " v" + getDescription().getVersion() + " enabled.");
    }

}
